@@ -1,5 +1,5 @@
 package List::Objects::WithUtils::Role::Array;
-$List::Objects::WithUtils::Role::Array::VERSION = '2.025001';
+$List::Objects::WithUtils::Role::Array::VERSION = '2.026001';
 use strictures 2;
 
 use Carp            ();
@@ -573,6 +573,24 @@ sub items_before_incl {
   )
 }
 
+sub pick {
+  return $_[0]->shuffle if $_[1] >= @{ $_[0] };
+  my %idx;
+  $idx{ int rand @{ $_[0] } } = 1 until keys %idx == $_[1];
+  blessed_or_pkg($_[0])->new(
+    @{ $_[0] }[keys %idx]
+  )
+}
+
+sub roll {
+  blessed_or_pkg($_[0])->new(
+    @{ $_[0] }[ 
+      map {; int rand @{ $_[0] } }
+        0 ..  (defined $_[1] ? $_[1] : @{ $_[0] }) - 1
+    ]
+  )
+}
+
 sub shuffle {
   blessed_or_pkg($_[0])->new(
     List::Util::shuffle( @{ $_[0] } )
@@ -584,6 +602,11 @@ sub uniq {
   blessed_or_pkg($_[0])->new( CORE::grep {; not $s{$_}++ } @{ $_[0] } )
 }
 
+sub repeated {
+  my %s;
+  blessed_or_pkg($_[0])->new( CORE::grep {; $s{$_}++ == 1 } @{ $_[0] } )
+}
+
 sub sort_by {
   blessed_or_pkg($_[0])->new(
     __sort_by( $_[1], @{ $_[0] } )
@@ -1060,6 +1083,18 @@ L<List::Objects::WithUtils::Hash>.
 
 (Available from v2.23.1)
 
+=head3 pick
+
+  my $picked = array('a' .. 'f')->pick(3);
+
+Returns a new array object containing the specified number of elements chosen
+randomly and without repetition.
+
+If the given number is equal to or greater than the number of elements in the
+list, C<pick> will return a shuffled list (same as calling L</shuffle>).
+
+(Available from v2.26.1)
+
 =head3 random
 
 Returns a random element from the array.
@@ -1068,6 +1103,16 @@ Returns a random element from the array.
 
 Returns a new array object consisting of the reversed list of elements.
 
+=head3 roll
+
+Much like L</pick>, but repeated entries in the resultant list are allowed,
+and the number of entries to return may be larger than the size of the array.
+
+If the number of elements to return is not specified, the size of the original
+array is used.
+
+(Available from v2.26.1)
+
 =head3 rotate
 
   my $leftwards  = $array->rotate;
@@ -1373,6 +1418,17 @@ Uses L<List::UtilsBy::XS> if available.
 
 Like L</sort_by>, but using numerical comparison.
 
+=head3 repeated
+
+  my $repeats = $array->repeated;
+
+The opposite of L</uniq>; returns a new array object containing only repeated
+elements.
+
+(The same constraints apply with regards to stringification; see L</uniq>)
+
+(Available from v2.26.1)
+
 =head3 uniq
 
   my $unique = $array->uniq;
